@@ -1,3 +1,2 @@
 from .textcut import TextCut
-from .lang import *
-
+from .localisation import *
